@@ -1,14 +1,19 @@
 #!/bin/sh
 
+package=expeyes
+
 version=$2
-orig_tgz=$(basename $3)
-newdir=$(echo $orig_tgz | sed -e 's/.orig.tar.gz//' -e 's/_/-/')
+newdir=../${package}-${version}+dfsg
+orig_tgz=../${package}_${version}+dfsg.orig.tar.gz
 
 wd=$(pwd)
 
-cd ..
-tar xzf $orig_tgz
-mv expeyes-programs-$version $newdir
+mkdir tmp
+
+tar xzf $3 -C tmp
+mv tmp/expeyes-programs-$version $newdir
+rmdir tmp
+
 cd $newdir
 # remove symlinks pointing outside the source tree
 # fix for a lintian error.
@@ -17,6 +22,10 @@ for f in $(find . -type l); do
 	rm $f
     fi
 done
+
+# remove sourceless javascript files
+find expeyes-web -name "*.min.js" | xargs rm -f
+
 mkdir doc
 cd doc
 wget https://github.com/expeyes/expeyes-doc/archive/master.zip
@@ -26,11 +35,11 @@ mv expeyes-doc-master/* .
 rm master.zip
 rmdir expeyes-doc-master
 
-cd ../..
+cd $wd
 
-rm $orig_tgz v${version}.tar.gz
+rm $3 ../v${version}.tar.gz
 
 tar czf $orig_tgz $newdir
-rm -rf $newdir
+# rm -rf $newdir
 
-echo "Created ../$orig_tgz"
+echo "Created $orig_tgz and $newdir"
